﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Security.Cryptography.X509Certificates;
using System.Text;

namespace VRBankAPI
{
    public class EnhancedWebClient : WebClient
    {
        public string UserAgent { get; set; }
        public string ContentType { get; set; }
        public HttpWebRequest LastRequest { get; set; }

        private readonly CookieContainer container = new CookieContainer();

        public EnhancedWebClient(CookieContainer cookieContainer)
        {
            container = cookieContainer;
        }
        
        protected override WebRequest GetWebRequest(Uri address)
        {
            HttpWebRequest request = base.GetWebRequest(address) as HttpWebRequest;
            request.CookieContainer = container;
            ServicePointManager.ServerCertificateValidationCallback += delegate { return true; };
            request.ContentType = ContentType;
            request.AutomaticDecompression = DecompressionMethods.Deflate | DecompressionMethods.GZip;
            if (!String.IsNullOrEmpty(UserAgent))
                request.UserAgent = UserAgent;

            LastRequest = request;
            return request;
        }

        protected override WebResponse GetWebResponse(WebRequest request)
        {
            WebResponse response = base.GetWebResponse(request);
            ReadCookies(response);
            return response;
        }

        private void ReadCookies(WebResponse r)
        {
            var response = r as HttpWebResponse;
            if (response != null)
            {
                CookieCollection cookies = response.Cookies;
                container.Add(cookies);
            }
        }
    }
}
